@@ -11,7 +11,10 @@ class BooleanType(Type):
         return f"BooleanType({self.value})"
     
     def __init__(self, value, **kwargs):
-        kwargs['value'] = value
+        if isinstance(value, BooleanType):
+            kwargs['value'] = value.value
+        else:
+            kwargs['value'] = value
         if isinstance(kwargs['value'], np.ndarray):
             kwargs['value'] = kwargs['value'].tolist()
         super().__init__(**kwargs)
