@@ -1,5 +1,5 @@
 from .DIP_Node import Node
-from ..solvers import LogicalSolver
+from ..solvers import LogicalSolver, FunctionSolver
 from ..datatypes import BooleanType
 
 class BooleanNode(Node):
@@ -32,7 +32,10 @@ class BooleanNode(Node):
             self.value = BooleanType(value)
             
     def parse(self, env):
-        if self.value_expr: # Process function
+        if self.value_fn: # Process function
+             with FunctionSolver(env) as s:
+                self.value_raw = s.solve(self.value_fn)
+        if self.value_expr: # Process expression
             with LogicalSolver(env) as s:
                 self.value_raw = s.solve(self.value_expr)
         if self.units_raw:
