@@ -1,7 +1,11 @@
+import os
+from pathlib import Path
+
 import dipsl
 from . import Node
 from . import Parser
 from ..settings import Namespace
+from ..DIP_Source import Source
 
 class SourceNode(Node):
     keyword: str = 'source'
@@ -16,7 +20,6 @@ class SourceNode(Node):
     def parse(self, env):
         parser = Parser(
             code=self.value_raw,
-            line=self.line,
             source=self.source
         )
         # import a remote source
@@ -24,7 +27,7 @@ class SourceNode(Node):
         if parser.is_parsed('part_reference'):
             sources = env.request(parser.value_ref, namespace=Namespace.SOURCES)
             for key, val in sources.items():
-                env.add_source(key, val)
+                env.add_source(key, val.source, val.path)
         else:
             # inject value of a node
             parser.part_name(path=False) # parse name
@@ -33,11 +36,18 @@ class SourceNode(Node):
             if parser.value_ref:
                 self.inject_value(env, parser)
             if parser.value_raw.endswith('dip'):
-                p = dipsl.DIP()
+                source = Source(**self.source.__dict__)
+                source.primary = False
+                p = dipsl.DIP(source=source)
                 p.from_file(parser.value_raw)
                 p.parse()
-                env.add_source(parser.name, p)
+                env.add_source(parser.name, p, parser.value_raw)
             else:
-                with open(parser.value_raw,'r') as f:
-                    env.add_source(parser.name, f.read())
+                filepath = parser.value_raw
+                if not os.path.isabs(filepath):
+                    # set relative paths with respect to the source script
+                    parent = Path(self.source.filename).parent
+                    filepath = parent / filepath
+                with open(filepath,'r') as f:
+                    env.add_source(parser.name, f.read(), filepath)
         return None
