@@ -2,7 +2,7 @@ from typing import List
 from pydantic import BaseModel
 
 from .DIP_Node import Node
-from ..solvers import TemplateSolver
+from ..solvers import TemplateSolver, FunctionSolver
 from ..datatypes import StringType
 
 class StringNode(Node):
@@ -34,8 +34,11 @@ class StringNode(Node):
             self.value = None
             
     def parse(self, env):
+        if self.value_fn: # Process function
+            with FunctionSolver(env) as s:
+                self.value_raw = s.solve(self.value_fn)
         if self.value_expr: # Process function
-            with TemplateSolver(env) as s:
+            with TemplateSolver(env, source=self.source) as s:
                 self.value_raw = s.solve(self.value_expr)
         if self.units_raw:
             raise Exception('String datatype does not support units:', self.code)
